==> ucommon-4.0.2.tar.gz: ucommon-4.0.2/doxy.config.cmake <==
PROJECT_NAME    = "@PROJECT_NAME@"
OUTPUT_DIRECTORY = doc
OUTPUT_LANGUAGE = English
FULL_PATH_NAMES = YES
STRIP_FROM_PATH = @CMAKE_CURRENT_SOURCE_DIR@/inc
SHORT_NAMES = YES
TAB_SIZE = 4
INPUT = @CMAKE_CURRENT_SOURCE_DIR@/inc/ucommon/platform.h @CMAKE_CURRENT_SOURCE_DIR@/inc/ucommon
EXAMPLE_PATH = @CMAKE_CURRENT_SOURCE_DIR@/test
FILE_PATTERNS = *.h
RECURSIVE = NO
ALIASES = "license=\par License:\n"
JAVADOC_AUTOBRIEF = YES
OPTIMIZE_OUTPUT_FOR_C = YES
OPTIMIZE_OUTPUT_JAVA = NO
EXTRACT_ALL = NO
EXTRACT_PRIVATE = NO
EXTRACT_STATIC = NO
HIDE_UNDOC_CLASSES = YES
HIDE_UNDOC_MEMBERS = NO
CASE_SENSE_NAMES = NO
SHOW_INCLUDE_FILES = YES
SORT_BY_SCOPE_NAME = YES
SORT_GROUP_NAMES = YES
SORT_BRIEF_DOCS = YES
SORT_MEMBER_DOCS = YES
SEARCH_INCLUDES = YES
INCLUDE_PATH = inc /usr/include /usr/local/include
GENERATE_TODOLIST = YES
GENERATE_TESTLIST = YES
GENERATE_BUGLIST = YES
GENERATE_DEPRECATEDLIST = YES
MAX_INITIALIZER_LINES = 30
SHOW_USED_FILES = YES
INLINE_SOURCES = NO
STRIP_CODE_COMMENTS = YES
ALPHABETICAL_INDEX = YES
COLS_IN_ALPHA_INDEX = 5
GENERATE_HTML = YES
HTML_ALIGN_MEMBERS = YES
GENERATE_HTMLHELP = YES
GENERATE_TREEVIEW = YES
TREEVIEW_WIDTH = 256
GENERATE_LATEX = YES
COMPACT_LATEX = YES
PDF_HYPERLINKS = YES
USE_PDFLATEX = NO
LATEX_BATCHMODE = YES
LATEX_HIDE_INDICES = NO
GENERATE_RTF = YES
COMPACT_RTF = YES
RTF_HYPERLINKS = NO
GENERATE_MAN = NO
GENERATE_XML = NO
GENERATE_PERLMOD = NO
ENABLE_PREPROCESSING = YES
MACRO_EXPANSION = YES
EXPAND_ONLY_PREDEF = NO
SEARCH_INCLUDES = YES
PREDEFINED = AF_INET6 NEW_STDCPP
CLASS_DIAGRAMS = YES
COLLABORATION_GRAPH = YES
HIDE_UNDOC_RELATIONS = NO
HAVE_DOT = YES
CLASS_GRAPH = YES
INCLUDE_GRAPH = YES
INCLUDED_BY_GRAPH = YES
CALL_GRAPH = YES
SOURCE_BROWSER = YES
GRAPHICAL_HIERARCHY = YES
DOT_IMAGE_FORMAT = png
DOT_TRANSPARENT = YES
# MAX_DOT_GRAPH_WIDTH = 1024
# MAX_DOT_GRAPH_HEIGHT = 1024
TEMPLATE_RELATIONS = NO
GENERATE_LEGEND = YES
SEARCHENGINE = NO
WARN_IF_UNDOCUMENTED = NO

==> ucommon-6.0.3.tar.gz: ucommon-6.0.3/doxy.config.cmake <==
PROJECT_NAME    = "@PROJECT_NAME@"
OUTPUT_DIRECTORY = @CMAKE_CURRENT_BINARY_DIR@/doc
OUTPUT_LANGUAGE = English
FULL_PATH_NAMES = YES
STRIP_FROM_PATH = @CMAKE_CURRENT_SOURCE_DIR@/inc
SHORT_NAMES = YES
TAB_SIZE = 4
INPUT = @CMAKE_CURRENT_SOURCE_DIR@/inc/ucommon @CMAKE_CURRENT_SOURCE_DIR@/inc/commoncpp
EXAMPLE_PATH = @CMAKE_CURRENT_SOURCE_DIR@/test
FILE_PATTERNS = *.h
RECURSIVE = NO
ALIASES = "license=\par License:\n"
JAVADOC_AUTOBRIEF = YES
OPTIMIZE_OUTPUT_FOR_C = YES
OPTIMIZE_OUTPUT_JAVA = NO
EXTRACT_ALL = NO
EXTRACT_PRIVATE = NO
EXTRACT_STATIC = NO
HIDE_UNDOC_CLASSES = YES
HIDE_UNDOC_MEMBERS = NO
CASE_SENSE_NAMES = NO
SHOW_INCLUDE_FILES = YES
SORT_BY_SCOPE_NAME = YES
SORT_GROUP_NAMES = YES
SORT_BRIEF_DOCS = YES
SORT_MEMBER_DOCS = YES
SEARCH_INCLUDES = YES
INCLUDE_PATH = @CMAKE_CURRENT_SOURCE_DIR@/inc @CMAKE_CURRENT_SOURCE_DIR@/inc/ucommon @CMAKE_CURRENT_SOURCE_DIR@/inc/commoncpp /usr/include /usr/local/include
GENERATE_TODOLIST = YES
GENERATE_TESTLIST = YES
GENERATE_BUGLIST = YES
GENERATE_DEPRECATEDLIST = YES
MAX_INITIALIZER_LINES = 30
SHOW_USED_FILES = YES
INLINE_SOURCES = NO
STRIP_CODE_COMMENTS = YES
ALPHABETICAL_INDEX = YES
COLS_IN_ALPHA_INDEX = 5
GENERATE_HTML = YES
HTML_ALIGN_MEMBERS = YES
GENERATE_HTMLHELP = YES
GENERATE_TREEVIEW = YES
TREEVIEW_WIDTH = 256
GENERATE_LATEX = YES
COMPACT_LATEX = YES
PDF_HYPERLINKS = YES
USE_PDFLATEX = NO
LATEX_BATCHMODE = YES
LATEX_HIDE_INDICES = NO
GENERATE_RTF = YES
COMPACT_RTF = YES
RTF_HYPERLINKS = NO
GENERATE_MAN = NO
GENERATE_XML = NO
GENERATE_PERLMOD = NO
ENABLE_PREPROCESSING = YES
MACRO_EXPANSION = YES
EXPAND_ONLY_PREDEF = NO
SEARCH_INCLUDES = YES
PREDEFINED = AF_INET6 NEW_STDCPP
CLASS_DIAGRAMS = YES
COLLABORATION_GRAPH = YES
HIDE_UNDOC_RELATIONS = NO
HAVE_DOT = YES
CLASS_GRAPH = YES
INCLUDE_GRAPH = YES
INCLUDED_BY_GRAPH = YES
CALL_GRAPH = YES
SOURCE_BROWSER = YES
GRAPHICAL_HIERARCHY = YES
DOT_IMAGE_FORMAT = png
DOT_TRANSPARENT = YES
# MAX_DOT_GRAPH_WIDTH = 1024
# MAX_DOT_GRAPH_HEIGHT = 1024
TEMPLATE_RELATIONS = NO
GENERATE_LEGEND = YES
SEARCHENGINE = NO
WARN_IF_UNDOCUMENTED = NO
